@@ -5,4 +5,6 @@ from .sac import SACPolicy
 from .sacn import SACNPolicy
 from .xql import XQLPolicy
 from .td3 import TD3Policy
-from .td3bc import TD3BCPolicy
\ No newline at end of file
+from .td3bc import TD3BCPolicy
+from .awac import AWACPolicy
+from .inac import InACPolicy
\ No newline at end of file
